import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)


/**
 * A simple label for writing text.
 *
 * @author Ed Parrish
 * @version 1.1  8/06/2011
 */
public class Label extends Actor
{
    /**
     * Constructs a label of the specified size with black text
     * on a clear background.
     *
     * @param text The text to display on the label
     * @param size The font size with which to display the text.
     */
    public Label(String text, int size) {
        this (text, size, Color.BLACK, new Color(0, 0, 0, 0));
    }

    /**
     * Constructs a label of the specified size and text color
     * on a clear background.
     *
     * @param text The text to display on the label
     * @param size The font size with which to display the text.
     * @param textColor The color to use for displaying text.
     */
    public Label(String text, int size, Color textColor) {
        this (text, size, textColor, new Color(0, 0, 0, 0));
    }

    /**
     * Constructs a label with text of the specified color on a background
     * of the specified color.
     *
     * @param text The text to display on the label
     * @param size The font size with which to display the text.
     * @param textColor The color to use for displaying text.
     * @param bgColor The desired background color.
     */
    public Label(String text, int size, Color textColor, Color bgColor) {
        GreenfootImage img = new GreenfootImage(text, size,
            textColor, bgColor);
        setImage(img);
    }
}
